pub enum PaintState {
PendingGpuResources {
window: Arc<dyn Window>,
rx: Receiver<Result<(GpuResources, Surface<'static>), GpuResourceError>>,
font_embolden: f32,
renderer: Renderer,
},
Initialized {
renderer: Renderer,
},
}Variants
PendingGpuResources
The renderer is not yet initialized. This state is used to wait for the GPU resources to be acquired.
Fields

rx: Receiver<Result<(GpuResources, Surface<'static>), GpuResourceError>>
renderer: RendererThis field holds an instance of Renderer::Uninitialized until the GPU resources are acquired,
which will be returned in PaintState::renderer and PaintState::renderer_mut.
All calls to renderer methods will be no-ops until the renderer is initialized.
Previously, PaintState::renderer and PaintState::renderer_mut would panic if called when the renderer was uninitialized.
However, this turned out to be hard to handle properly and led to panics, especially since the rest of the application code can’t control when the renderer is initialized.
Initialized
The renderer is initialized and ready to paint.
Implementations
Sourceimpl PaintState
impl PaintState
pub fn new_pending( window: Arc<dyn Window>, rx: Receiver<Result<(GpuResources, Surface<'static>), GpuResourceError>>, size: Size, font_embolden: f32, ) -> Self
pub fn new( window: Arc<dyn Window>, surface: Surface<'static>, gpu_resources: GpuResources, scale: f64, size: Size, font_embolden: f32, ) -> Self
pub fn new_skia( window: Arc<dyn Window>, scale: f64, size: Size, font_embolden: f32, ) -> Self