pub struct PaintCx<'a> {
pub window_state: &'a mut WindowState,
pub target_id: ElementId,
pub world_transform: Affine,
pub layout_rect_local: Rect,
pub clip: Option<RoundedRect>,
pub font_size_cx: FontSizeCx,
/* private fields */
}Expand description
Per-target paint context - created for each visual node Similar to EventCx in event dispatch
Fields
window_state: &'a mut WindowStateReference to global paint state
target_id: ElementIdThe target visual node being painted (CRITICAL for views with multiple visuals)
world_transform: AffineWorld transform for this visual node (from box tree)
layout_rect_local: RectLocal layout bounds for this visual node (from box tree)
clip: Option<RoundedRect>Optional clip for this visual node (from box tree)
font_size_cx: FontSizeCxImplementations
Sourceimpl PaintCx<'_>
impl PaintCx<'_>
Sourcepub fn is_drag_paint(&self, id: impl Into<ElementId>) -> bool
pub fn is_drag_paint(&self, id: impl Into<ElementId>) -> bool
Allows a View to determine if it is being called in order to
paint a draggable image of itself during a drag (likely
draggable() was called on the View or ViewId) as opposed
to a normal paint in order to alter the way it renders itself.
Sourcepub fn clear_clip(&mut self)
pub fn clear_clip(&mut self)
Clear clip